
# econnlp: An Econ Approach to NLP

Please contact the authors below if you find any bugs or have any suggestions for improvement. Thank you!

Author: Nicolaj Søndergaard Mühlbach (n.muhlbach at gmail dot com, muhlbach at mit dot edu) 

## Code dependencies
This code has the following dependencies:
- Python >=3.6
- pandas >=1.3

## Installation

## Usage

```python
# Coming soon
```
<!-- ## Example
We provide an example script in `demo.py`. -->
